@@ -16,4 +16,14 @@ NULL
 #'  @format A data set with 254 observations of 3 variables. 
 #'  @name MisLinks 
 #'
+NULL
+
+#' JSON data file of the Flare class hierarchy.
+#'
+#' @docType data
+#' @source See Mike Bostock \url{http://bl.ocks.org/mbostock/4063550}.
+#' @keywords datasets
+#' @format A JSON file with two arrays \code{name} and \code{children}.
+#' @name flare
+#' 
 NULL
\ No newline at end of file
